@@ -10,9 +10,12 @@ from torch.utils.tensorboard import SummaryWriter
 from spotPython.hyperparameters.values import (
     add_core_model_to_fun_control,
     get_core_model_from_name,
+    get_river_core_model_from_name,
     get_metric_sklearn,
     get_prep_model,
+    get_river_prep_model,
 )
+from spotRiver.hyperdict.river_hyper_dict import RiverHyperDict
 
 
 def fun_control_init(
@@ -37,6 +40,7 @@ def fun_control_init(
     devices=1,
     enable_progress_bar=False,
     EXPERIMENT_NAME=None,
+    eval=None,
     fun_evals=15,
     fun_repeats=1,
     horizon=None,
@@ -125,6 +129,9 @@ def fun_control_init(
             The experimental design object. Default is None.
         enable_progress_bar (bool):
             Whether to enable the progress bar or not.
+        eval (str):
+            evaluation method used in sklearn taintest.py.
+            Can be "eval_test", "eval_oon_score", "train_cv" or None. Default is None.
         EXPERIMENT_NAME (str):
             The name of the experiment. If EXPERIMENT_NAME is not None,
             the spot_tensorboard_path is compiled and
@@ -351,8 +358,6 @@ def fun_control_init(
 
     if metric_sklearn is None and metric_sklearn_name is not None:
         metric_sklearn = get_metric_sklearn(metric_sklearn_name)
-    if prep_model is None and prep_model_name is not None:
-        prep_model = get_prep_model(prep_model_name)
 
     fun_control = {
         "PREFIX": PREFIX,
@@ -378,7 +383,7 @@ def fun_control_init(
         "device": device,
         "devices": devices,
         "enable_progress_bar": enable_progress_bar,
-        "eval": None,
+        "eval": eval,
         "fun_evals": fun_evals,
         "fun_repeats": fun_repeats,
         "horizon": horizon,
@@ -437,7 +442,20 @@ def fun_control_init(
         "weights_entry": weights_entry,
     }
     if hyperdict is not None and core_model_name is not None:
-        coremodel, core_model_instance = get_core_model_from_name(core_model_name)
+        # check if hyperdict implements the methods get_scenario:
+        if hasattr(hyperdict, "get_scenario"):
+            scenario = hyperdict().get_scenario()
+        else:
+            scenario = None
+        if fun_control["hyperdict"].__name__ == RiverHyperDict.__name__ or scenario == "river":
+            coremodel, core_model_instance = get_river_core_model_from_name(core_model_name)
+            if prep_model is None and prep_model_name is not None:
+                prep_model = get_river_prep_model(prep_model_name)
+        else:
+            coremodel, core_model_instance = get_core_model_from_name(core_model_name)
+            if prep_model is None and prep_model_name is not None:
+                prep_model = get_prep_model(prep_model_name)
+        fun_control.update({"prep_model": prep_model})
         add_core_model_to_fun_control(
             core_model=core_model_instance,
             fun_control=fun_control,
